mzdata provides basic access to raw and processed mass spectrometry data formats in
Rust.
mzdata requires a lot of parsing machinery which can make it a weighty dependency to
to add to a project.
Modules
- io
- Reading and writing mass spectrometry data file formats and abstractions over them.
- meta
- Metadata describing mass spectrometry data files and their contents.
- mzpeaks
mzpeaksimplements the building blocks and machinery for representing peaks in a mass spectrum.- params
- Elements of controlled vocabularies used to describe mass spectra and their components.
- prelude
- A set of foundational traits used throughout the library.
- spectrum
- The data structures and components that represent a mass spectrum and how to access their data.
- utils
Macros
- curie
- cvmap
- delegate_
impl_ metadata_ trait - Delegates the implementation of
MSDataFileMetadatato a member. Passing an extra levelextendedtoken implements the optional methods. - find_
param_ method - impl_
metadata_ trait - Assumes a field for the non-
Optionfacets of theMSDataFileMetadataimplementation are present. Passing an extra levelextendedtoken implements the optional methods. - impl_
param_ described - Implement the
ParamDescribedtrait for type$t, referencing aparamsmember of typeVec<Param>. - impl_
param_ described_ deferred - Implement the
ParamDescribedtrait for type$t, referencing aparamsmember that is anOption<Vec<Param>>that will lazily be initialized automatically when it is accessed mutably. - mz_read
- A macro that dynamically works out how to get a
SpectrumSource-derived object from a path orio::Read+io::Seekboxed object. This is meant to be a convenience for working with a scoped file reader without penalty. - mz_
write - A macro that dynamically works out how to get a
SpectrumWriterfrom a path orio::Writeboxed object.
Structs
- MZReader
Builder - A builder type for
MZReaderType. - Param
- A controlled vocabulary or user parameter
- RawSpectrum
- Represents a spectrum that hasn’t been processed yet, with only data arrays, potentially no discrete peaks. A raw spectrum may still be centroided, but the peaks still need to be decoded.
Type Aliases
- Centroid
Spectrum - MZReader
- A specialization of
MZReaderTypefor the default peak types, for common use. The preferred means of creating an instance is using theMZReader::open_pathfunction. - Param
List - Spectrum
- A ready-to-use parameterized type for representing a spectrum in multiple overlapping layers.