pub enum IonMobilityFrameAccessError {
FrameNotFound,
FrameIdNotFound(String),
FrameIndexNotFound(usize),
IOError(Option<Error>),
}Expand description
Errors that may occur when reading a spectrum from a RandomAccessIonMobilityFrameIterator
Variants
FrameNotFound
An undetermined error failing to locate the requested frame
FrameIdNotFound(String)
An error resolving a frame by it’s native ID
FrameIndexNotFound(usize)
An error resolving a frame by it’s index
IOError(Option<Error>)
An I/O error prevented reading the frame, even if it could be found.