pub struct StreamingSpectrumIterator<C, D, S, I>{ /* private fields */ }Expand description
An alternative implementation of SpectrumSource for non-rewindable underlying iterators.
When the source doesn’t support io::Seek, most reader types don’t
even implement SpectrumSource, although they still implement
Iterator. The StreamingSpectrumIterator
wrapper does implement parts of SpectrumSource using less efficient
mechanism, but in situations where it cannot satisfy the request, it will panic instead. It also,
naturally doesn’t support reading spectra that have already been seen as the stream cannot be reversed.
Implementations
Sourceimpl<C, D, S, I> StreamingSpectrumIterator<C, D, S, I>
impl<C, D, S, I> StreamingSpectrumIterator<C, D, S, I>
pub fn new(source: I) -> StreamingSpectrumIterator<C, D, S, I> ⓘ
pub fn get_inner(&self) -> &I
pub fn get_mut(&mut self) -> &mut I
Sourcepub fn iter_buffer(&self) -> Iter<'_, S>
pub fn iter_buffer(&self) -> Iter<'_, S>
Get an immutable iterator over the pre-filled buffer.
See also
Sourcepub fn populate_buffer(&mut self, size: usize)
pub fn populate_buffer(&mut self, size: usize)
Fill the buffer with at most size spectra