MassSpectrometerFileFormatTerm

Enum MassSpectrometerFileFormatTerm 

pub enum MassSpectrometerFileFormatTerm {
Show 47 variants WatersRaw, MassSpectrometerFile, ABIWIFF, ThermoRAW, PSIMzData, MicromassPKL, ISBMzXML, BrukerAgilentYEP, MzML, DTA, ProteinLynxGlobalServerMassSpectrumXML, ParameterFile, BioworksSRF, BrukerBAF, BrukerU2, BrukerFID, ShimadzuBiotechDatabaseEntity, MascotMGF, MobilionMBI, PerSeptivePKS, SCIEXAPIIII, BrukerXML, Text, PhenyxXML, MS2, SCIEXTOFTOFDatabase, AgilentMassHunter, ProteinscapeSpectra, SCIEXTOFTOFT2D, Mz5, BrukerContainer, SCiLSLab, AndiMS, UIMF, MS1, BrukerTDF, MzMLb, Msalign, Feature, Chrom, AndromedaAplFile, ShimadzuBiotechLCD, BrukerTSF, OpenChromatographyBinaryOCB, SCIEXWIFF2, MzPeak, ImzML,
}

Variants



WatersRaw

Waters raw format - Waters data file format found in a Waters RAW directory, generated from an MS acquisition.



MassSpectrometerFile

mass spectrometer file format - The format of the file being used. This could be a instrument or vendor specific proprietary file format or a converted open file format.



ABIWIFF

ABI WIFF format - Applied Biosystems WIFF file format.



ThermoRAW

Thermo RAW format - Thermo Scientific RAW file format.



PSIMzData

PSI mzData format - Proteomics Standards Initiative mzData file format.



MicromassPKL

Micromass PKL format - Micromass PKL file format.



ISBMzXML

ISB mzXML format - Institute of Systems Biology mzXML file format.



BrukerAgilentYEP

Bruker/Agilent YEP format - Bruker/Agilent YEP file format.



MzML

mzML format - Proteomics Standards Initiative mzML file format.



DTA

DTA format - SEQUEST DTA file format.



ProteinLynxGlobalServerMassSpectrumXML

ProteinLynx Global Server mass spectrum XML format - Peak list file format used by ProteinLynx Global Server.



ParameterFile

parameter file - Parameter file used to configure the acquisition of raw data on the instrument.



BioworksSRF

Bioworks SRF format - Thermo Finnigan SRF file format.



BrukerBAF

Bruker BAF format - Bruker BAF raw file format.



BrukerU2

Bruker U2 format - Bruker HyStar U2 file format.



BrukerFID

Bruker FID format - Bruker FID file format.



ShimadzuBiotechDatabaseEntity

Shimadzu Biotech database entity - Shimadzu Biotech format.



MascotMGF

Mascot MGF format - Mascot MGF file format.



MobilionMBI

Mobilion MBI format - Mobilion MBI file format.



PerSeptivePKS

PerSeptive PKS format - PerSeptive peak list file format.



SCIEXAPIIII

SCIEX API III format - PE SCIEX peak list file format.



BrukerXML

Bruker XML format - Bruker data exchange XML format.



Text

text format - Simple text file format of ‘m/z [intensity]’ values for a PMF (or single MS2) search.



PhenyxXML

Phenyx XML format - Phenyx open XML file format.



MS2

MS2 format - MS2 file format for MS2 spectral data.



SCIEXTOFTOFDatabase

SCIEX TOF/TOF database - Applied Biosystems/MDS Analytical Technologies TOF/TOF instrument database.



AgilentMassHunter

Agilent MassHunter format - A data file format found in an Agilent MassHunter directory which contains raw data acquired by an Agilent mass spectrometer.



ProteinscapeSpectra

Proteinscape spectra - Spectra from Bruker/Protagen Proteinscape database.



SCIEXTOFTOFT2D

SCIEX TOF/TOF T2D format - Applied Biosystems/MDS Analytical Technologies TOF/TOF instrument export format.



Mz5

mz5 format - mz5 file format, modelled after mzML.



BrukerContainer

Bruker Container format - Bruker Container raw file format.



SCiLSLab

SCiLS Lab format - SCiLS Lab file format.



AndiMS

Andi-MS format - AIA Analytical Data Interchange file format for mass spectrometry data.



UIMF

UIMF format - SQLite-based file format created at Pacific Northwest National Lab. It stores an intermediate analysis of ion-mobility mass spectrometry data.



MS1

MS1 format - MS1 file format for MS1 spectral data.



BrukerTDF

Bruker TDF format - Bruker TDF raw file format.



MzMLb

mzMLb format - mzMLb file format, mzML encapsulated within HDF5.



Msalign

msalign format - msalign file format.



Feature

feature format - TopFD feature file format.



Chrom

chrom format - The Lipid Data Analyzer native chrom format.



AndromedaAplFile

Andromeda:apl file format - Peak list file format of the Andromeda search engine.



ShimadzuBiotechLCD

Shimadzu Biotech LCD format - Shimadzu Biotech LCD file format.



BrukerTSF

Bruker TSF format - Bruker TSF raw file format.



OpenChromatographyBinaryOCB

Open Chromatography Binary OCB format - ChemClipse/OpenChrom file format.



SCIEXWIFF2

SCIEX WIFF2 format - SCIEX WIFF2 file format.



MzPeak

mzPeak format - Proteomics Standards Initiatve mzPeak file format.



ImzML

imzML format - IMSIS imzML imaging file format.

Implementations

Source

impl MassSpectrometerFileFormatTerm

These methods are part of the controlled vocabulary mapping

pub const fn accession(&self) -> u32

Retrieve the accession number for this term, independent of its controlled vocabulary

pub const fn controlled_vocabulary(&self) -> ControlledVocabulary

Retrieve the controlled vocabulary this term belongs to

pub const fn name(&self) -> &'static str

Retrieve the plain text human readable name for this term

pub fn from_name(name: &str) -> Option<MassSpectrometerFileFormatTerm>

Attempt to map a string by name to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn from_accession( accession: u32, ) -> Option<MassSpectrometerFileFormatTerm>

Attempt to map the numeric accession number to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn to_param(self) -> ParamCow<'static>

Convert this term into a ParamCow without a value.

pub const fn from_curie(curie: &CURIE) -> Option<MassSpectrometerFileFormatTerm>

Convert a CURIE by accession.

If no match is found, None is returned.

pub const fn from_param( p: &ParamCow<'static>, ) -> Option<MassSpectrometerFileFormatTerm>

Attempt to convert a ParamCow to a term from this set.

If no match is found, None is returned.

Note

This method can be called in const contexts, requiring the type be ParamCow with a 'static lifetime parameter, but the regular From trait is implemented for all ParamLike types.

pub fn flags(&self) -> i32

Retrieve a term set specific set of flags

pub fn parents(&self) -> Vec<MassSpectrometerFileFormatTerm>

Retrieve the list of zero or more terms in the set which are parents of this term.