SpectrumType

Enum SpectrumType 

pub enum SpectrumType {
Show 18 variants MassSpectrum, ChargeInversionMassSpectrum, ConstantNeutralGainSpectrum, ConstantNeutralLossSpectrum, E2MassSpectrum, PrecursorIonSpectrum, ProductIonSpectrum, MS1Spectrum, MSnSpectrum, CRMSpectrum, SIMSpectrum, SRMSpectrum, PDASpectrum, EnhancedMultiplyChargedSpectrum, TimeDelayedFragmentationSpectrum, ElectromagneticRadiationSpectrum, EmissionSpectrum, AbsorptionSpectrum,
}
The kinds of spectrum that might be represented

Variants



MassSpectrum

mass spectrum - A plot of the relative abundance of a beam or other collection of ions as a function of the mass-to-charge ratio (m/z).



ChargeInversionMassSpectrum

charge inversion mass spectrum - The measurement of the relative abundance of ions that result from a charge inversion reaction as a function of m/z.



ConstantNeutralGainSpectrum

constant neutral gain spectrum - A spectrum formed of all product ions that have been produced by gain of a pre-selected neutral mass following the reaction with and addition of the gas in a collision cell.



ConstantNeutralLossSpectrum

constant neutral loss spectrum - A spectrum formed of all product ions that have been produced with a selected m/z decrement from any precursor ions. The spectrum shown correlates to the precursor ion spectrum. See also neutral loss spectrum.



E2MassSpectrum

e/2 mass spectrum - A mass spectrum obtained using a sector mass spectrometer in which the electric sector field E is set to half the value required to transmit the main ion-beam. This spectrum records the signal from doubly charged product ions of charge-stripping reactions.



PrecursorIonSpectrum

precursor ion spectrum - Spectrum generated by scanning precursor m/z while monitoring a fixed product m/z.



ProductIonSpectrum

product ion spectrum - OBSOLETE A mass spectrum recorded from any spectrometer in which the appropriate m/z separation scan function is set to record the product ion or ions of selected precursor ions.



MS1Spectrum

MS1 spectrum - Mass spectrum created by a single-stage MS experiment or the first stage of a multi-stage experiment.



MSnSpectrum

MSn spectrum - MSn refers to multi-stage MS2 experiments designed to record product ion spectra where n is the number of product ion stages (progeny ions). For ion traps, sequential MS/MS experiments can be undertaken where n > 2 whereas for a simple triple quadrupole system n=2. Use the term ms level (MS:1000511) for specifying n.



CRMSpectrum

CRM spectrum - Spectrum generated from MSn experiment with three or more stages of m/z separation and in which a particular multi-step reaction path is monitored.



SIMSpectrum

SIM spectrum - Spectrum obtained with the operation of a mass spectrometer in which the abundances of one ion or several ions of specific m/z values are recorded rather than the entire mass spectrum (Selected Ion Monitoring).



SRMSpectrum

SRM spectrum - Spectrum obtained when data are acquired from specific product ions corresponding to m/z values of selected precursor ions a recorded via two or more stages of mass spectrometry. The precursor/product ion pair is called a transition pair. Data can be obtained for a single transition pair or multiple transition pairs. Multiple time segments of different transition pairs can exist in a single file. Single precursor ions can have multiple product ions consitituting multiple transition pairs. Selected reaction monitoring can be performed as tandem mass spectrometry in time or tandem mass spectrometry in space.



PDASpectrum

PDA spectrum - OBSOLETE Spectrum generated from a photodiode array detector (ultraviolet/visible spectrum).



EnhancedMultiplyChargedSpectrum

enhanced multiply charged spectrum - MS1 spectrum that is enriched in multiply-charged ions compared to singly-charged ions.



TimeDelayedFragmentationSpectrum

time-delayed fragmentation spectrum - MSn spectrum in which the product ions are collected after a time delay, which allows the observation of lower energy fragmentation processes after precursor ion activation.



ElectromagneticRadiationSpectrum

electromagnetic radiation spectrum - A plot of the relative intensity of electromagnetic radiation as a function of the wavelength.



EmissionSpectrum

emission spectrum - A plot of the relative intensity of electromagnetic radiation emitted by atoms or molecules when excited.



AbsorptionSpectrum

absorption spectrum - A plot of the relative intensity of electromagnetic radiation absorbed by atoms or molecules when excited.

Implementations

Source

impl SpectrumType

These methods are part of the controlled vocabulary mapping

pub const fn accession(&self) -> u32

Retrieve the accession number for this term, independent of its controlled vocabulary

pub const fn controlled_vocabulary(&self) -> ControlledVocabulary

Retrieve the controlled vocabulary this term belongs to

pub const fn name(&self) -> &'static str

Retrieve the plain text human readable name for this term

pub fn from_name(name: &str) -> Option<SpectrumType>

Attempt to map a string by name to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn from_accession(accession: u32) -> Option<SpectrumType>

Attempt to map the numeric accession number to retrieve one of the terms from this set.

If no match is found, None is returned.

pub const fn to_param(self) -> ParamCow<'static>

Convert this term into a ParamCow without a value.

pub const fn from_curie(curie: &CURIE) -> Option<SpectrumType>

Convert a CURIE by accession.

If no match is found, None is returned.

pub const fn from_param(p: &ParamCow<'static>) -> Option<SpectrumType>

Attempt to convert a ParamCow to a term from this set.

If no match is found, None is returned.

Note

This method can be called in const contexts, requiring the type be ParamCow with a 'static lifetime parameter, but the regular From trait is implemented for all ParamLike types.

pub fn flags(&self) -> i32

Retrieve a term set specific set of flags

pub fn parents(&self) -> Vec<SpectrumType>

Retrieve the list of zero or more terms in the set which are parents of this term.

Source

impl SpectrumType

pub fn is_mass_spectrum(&self) -> bool

Check if this a mass spectrum or some other kind of spectrum

pub const fn default_main_axis(&self) -> ArrayType

Get the default measurement dimension for this kind of spectrum

pub const fn all_types() -> &'static [(SpectrumType, ParamCow<'static>)]

Get an array of all available types