pub struct Component {
pub component_type: ComponentType,
pub order: u8,
pub params: Vec<Param>,
}Expand description
A description of a combination of parts that are described as part of an InstrumentConfiguration.
There may be more than one component of the same type in a singel configuration, e.g. a triple-quad instrument
can have three separate ComponentType::Analyzer components.
A component may also be described by more than one Param, such as the
Fields
component_type: ComponentTypeThe kind of component this describes
order: u8The order in the sequence of components that the analytes interact with
params: Vec<Param>Implementations
Sourceimpl Component
impl Component
pub fn mass_analyzer(&self) -> Option<MassAnalyzerTerm>
pub fn detector(&self) -> Option<DetectorTypeTerm>
pub fn ionization_type(&self) -> Option<IonizationTypeTerm>
pub fn name(&self) -> Option<&str>
pub fn parent_types(&self) -> Vec<ParamCow<'static>>