pub struct NativeSpectrumIDFormat {
pub term: NativeSpectrumIdentifierFormatTerm,
/* private fields */
}Expand description
A text-based schema that defines how native spectrum identifiers are formatted.
These patterns are often found in mzML-compatible formats.
Fields
term: NativeSpectrumIdentifierFormatTermImplementations
Sourceimpl NativeSpectrumIDFormat
impl NativeSpectrumIDFormat
pub fn new(term: NativeSpectrumIdentifierFormatTerm) -> NativeSpectrumIDFormat
pub const fn name(&self) -> &str
pub const fn curie(&self) -> CURIE
Sourcepub fn parse<'h>(&self, ident: &'h str) -> Option<Captures<'h>>
pub fn parse<'h>(&self, ident: &'h str) -> Option<Captures<'h>>
This parses the provided string, returning the captured groups of the ID pattern if they are present
in a regex::Captures structure that can be indexed by group number.
Sourcepub fn parse_named<'h>(
&self,
ident: &'h str,
) -> Result<Vec<(Option<String>, &'h str)>, NativeIDFormatError>
pub fn parse_named<'h>( &self, ident: &'h str, ) -> Result<Vec<(Option<String>, &'h str)>, NativeIDFormatError>
This parses the provided string, returning the capture groups as (name, value) pairs they are present
Sourcepub fn format<'h>(
&self,
values: impl IntoIterator<Item = ValueRef<'h>>,
) -> Result<String, NativeIDFormatError>
pub fn format<'h>( &self, values: impl IntoIterator<Item = ValueRef<'h>>, ) -> Result<String, NativeIDFormatError>
Given the field values of a nativeID format, create string in that format