Sample

Struct Sample 

pub struct Sample {
    pub id: String,
    pub name: Option<String>,
    pub params: Vec<Param>,
}
A sample that was used to generate a MS dataset

Fields

id: String

A “unique” identifier

name: Option<String>

The sample’s human-friendly name

params: Vec<Param>

The controlled vocabulary and user parameters of the sample

Implementations

Source

impl Sample

pub fn new(id: String, name: Option<String>, params: Vec<Param>) -> Sample

pub fn number(&self) -> Option<ValueRef<'_>>

Find the sample number, if it is present

pub fn batch(&self) -> Option<ValueRef<'_>>

Find the sample batch, if it is present