Software

Struct Software 

pub struct Software {
    pub id: String,
    pub version: String,
    pub params: Vec<Param>,
}
A piece of software that was associated with the acquisition, transformation or otherwise processing of mass spectrometry data.

See https://peptideatlas.org/tmp/mzML1.1.0.html#software

Fields

id: String

A unique identifier for the software within processing metadata

version: String

A string denoting a particular software version, but does no guarantee is given for its format

params: Vec<Param>

Any associated vocabulary terms, including actual software name and type

Implementations

Source

impl Software

pub fn new(id: String, version: String, params: Vec<Param>) -> Software

pub fn find_software_term(&self) -> Option<SoftwareTerm>

Find the term defining the software

pub fn is_analysis(&self) -> bool

Is this software for analysis?

pub fn is_data_processing(&self) -> bool

Is this software for data processing?

pub fn is_acquisition(&self) -> bool

Is this software for data acquisition?

pub fn find_unique_id<'a>( id_stem: &str, softwares: impl IntoIterator<Item = &'a Software>, ) -> String

Find a unique identifier from an iterator over software IDs