pub struct SoftwareTypeFlags(/* private fields */);Expand description
A bit mask encoding the different kinds of software.
Implementations
Sourceimpl SoftwareType
impl SoftwareType
pub const None: SoftwareType
pub const Analysis: SoftwareType
pub const DataProcessing: SoftwareType
pub const Acquisition: SoftwareType
Sourceimpl SoftwareType
impl SoftwareType
Sourcepub const fn empty() -> SoftwareType
pub const fn empty() -> SoftwareType
Get a flags value with all bits unset.
Sourcepub const fn all() -> SoftwareType
pub const fn all() -> SoftwareType
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u8
pub const fn bits(&self) -> u8
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u8) -> Option<SoftwareType>
pub const fn from_bits(bits: u8) -> Option<SoftwareType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u8) -> SoftwareType
pub const fn from_bits_truncate(bits: u8) -> SoftwareType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u8) -> SoftwareType
pub const fn from_bits_retain(bits: u8) -> SoftwareType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<SoftwareType>
pub fn from_name(name: &str) -> Option<SoftwareType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: SoftwareType) -> bool
pub const fn intersects(&self, other: SoftwareType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: SoftwareType) -> bool
pub const fn contains(&self, other: SoftwareType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn insert(&mut self, other: SoftwareType)
pub fn insert(&mut self, other: SoftwareType)
The bitwise or (|) of the bits in two flags values.
Sourcepub fn remove(&mut self, other: SoftwareType)
pub fn remove(&mut self, other: SoftwareType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: SoftwareType)
pub fn toggle(&mut self, other: SoftwareType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: SoftwareType, value: bool)
pub fn set(&mut self, other: SoftwareType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: SoftwareType) -> SoftwareType
pub const fn intersection(self, other: SoftwareType) -> SoftwareType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: SoftwareType) -> SoftwareType
pub const fn union(self, other: SoftwareType) -> SoftwareType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: SoftwareType) -> SoftwareType
pub const fn difference(self, other: SoftwareType) -> SoftwareType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: SoftwareType) -> SoftwareType
pub const fn symmetric_difference(self, other: SoftwareType) -> SoftwareType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> SoftwareType
pub const fn complement(self) -> SoftwareType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SoftwareType
impl SoftwareType
Sourcepub const fn iter(&self) -> Iter<SoftwareType>
pub const fn iter(&self) -> Iter<SoftwareType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SoftwareType>
pub const fn iter_names(&self) -> IterNames<SoftwareType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.
Sourceimpl SoftwareType
impl SoftwareType
Sourcepub const fn is_analysis(&self) -> bool
pub const fn is_analysis(&self) -> bool
Is this software for analysis?
Sourcepub const fn is_data_processing(&self) -> bool
pub const fn is_data_processing(&self) -> bool
Is this software for data processing?
Sourcepub const fn is_acquisition(&self) -> bool
pub const fn is_acquisition(&self) -> bool
Is this software for data acquisition?