pub struct ValueType(/* private fields */);Expand description
A bit mask encoding the different value types a Param can take on, associated with a term.
Implementations
Sourceimpl ValueType
impl ValueType
pub const NoType: ValueType
pub const String: ValueType
pub const Integer: ValueType
pub const Float: ValueType
pub const Double: ValueType
pub const NonNegativeInteger: ValueType
pub const PositiveInteger: ValueType
pub const DateTime: ValueType
pub const Boolean: ValueType
pub const ListOf: ValueType
Sourceimpl ValueType
impl ValueType
Sourcepub const fn bits(&self) -> u16
pub const fn bits(&self) -> u16
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u16) -> Option<ValueType>
pub const fn from_bits(bits: u16) -> Option<ValueType>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u16) -> ValueType
pub const fn from_bits_truncate(bits: u16) -> ValueType
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u16) -> ValueType
pub const fn from_bits_retain(bits: u16) -> ValueType
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<ValueType>
pub fn from_name(name: &str) -> Option<ValueType>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: ValueType) -> bool
pub const fn intersects(&self, other: ValueType) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: ValueType) -> bool
pub const fn contains(&self, other: ValueType) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: ValueType)
pub fn remove(&mut self, other: ValueType)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: ValueType)
pub fn toggle(&mut self, other: ValueType)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: ValueType, value: bool)
pub fn set(&mut self, other: ValueType, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: ValueType) -> ValueType
pub const fn intersection(self, other: ValueType) -> ValueType
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: ValueType) -> ValueType
pub const fn union(self, other: ValueType) -> ValueType
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: ValueType) -> ValueType
pub const fn difference(self, other: ValueType) -> ValueType
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: ValueType) -> ValueType
pub const fn symmetric_difference(self, other: ValueType) -> ValueType
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> ValueType
pub const fn complement(self) -> ValueType
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl ValueType
impl ValueType
Sourcepub const fn iter(&self) -> Iter<ValueType>
pub const fn iter(&self) -> Iter<ValueType>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<ValueType>
pub const fn iter_names(&self) -> IterNames<ValueType>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.