MSDataFileMetadata

Trait MSDataFileMetadata 

pub trait MSDataFileMetadata {
Show 18 methods // Required methods fn data_processings(&self) -> &Vec<DataProcessing>; fn instrument_configurations( &self, ) -> &HashMap<u32, InstrumentConfiguration>; fn file_description(&self) -> &FileDescription; fn softwares(&self) -> &Vec<Software>; fn samples(&self) -> &Vec<Sample>; fn data_processings_mut(&mut self) -> &mut Vec<DataProcessing>; fn instrument_configurations_mut( &mut self, ) -> &mut HashMap<u32, InstrumentConfiguration>; fn file_description_mut(&mut self) -> &mut FileDescription; fn softwares_mut(&mut self) -> &mut Vec<Software>; fn samples_mut(&mut self) -> &mut Vec<Sample>; // Provided methods fn scan_settings(&self) -> Option<&Vec<ScanSettings>> { ... } fn scan_settings_mut(&mut self) -> Option<&mut Vec<ScanSettings>> { ... } fn copy_metadata_from(&mut self, source: &impl MSDataFileMetadata) where Self: Sized { ... } fn spectrum_count_hint(&self) -> Option<u64> { ... } fn set_spectrum_count_hint(&mut self, _value: Option<u64>) { ... } fn run_description(&self) -> Option<&MassSpectrometryRun> { ... } fn run_description_mut(&mut self) -> Option<&mut MassSpectrometryRun> { ... } fn source_file_name(&self) -> Option<&str> { ... }
}
Mass spectrometry data files have several facets of descriptive metadata

Required Methods

fn data_processings(&self) -> &Vec<DataProcessing>

The series of DataProcessing workflows applied to spectra in this data file.

fn instrument_configurations(&self) -> &HashMap<u32, InstrumentConfiguration>

A mapping over different InstrumentConfiguration modes that spectra were acquired under.

fn file_description(&self) -> &FileDescription

A description of the contents and the sources for this mass spectrometry data file.

fn softwares(&self) -> &Vec<Software>

The series of Software applied to the data file to apply different DataProcessing methods.

fn samples(&self) -> &Vec<Sample>

A list of sample descriptions that were measured in this data file if available.

fn data_processings_mut(&mut self) -> &mut Vec<DataProcessing>

Mutably access the DataProcessing list for this data file

fn instrument_configurations_mut( &mut self, ) -> &mut HashMap<u32, InstrumentConfiguration>

Mutably access the InstrumentConfiguration mapping for this data file

fn file_description_mut(&mut self) -> &mut FileDescription

Mutably access the FileDescription description of the contents and the sources for this mass spectrometry data file.

fn softwares_mut(&mut self) -> &mut Vec<Software>

Mutably access the list of Software of this data file.

fn samples_mut(&mut self) -> &mut Vec<Sample>

Provided Methods

fn scan_settings(&self) -> Option<&Vec<ScanSettings>>

A list of scan settings in ScanSettings pre-configured by the instrument operator prior to the start of data acquisition.

This information is relatively unstructured and unless manually specified will be absent from most formats.

fn scan_settings_mut(&mut self) -> Option<&mut Vec<ScanSettings>>

Mutably access the list of ScanSettings for this dataset. Most formats do not possess a related concept and will not carry one.

fn copy_metadata_from(&mut self, source: &impl MSDataFileMetadata)
where Self: Sized,

Copy the metadata from another MSDataFileMetadata implementation into this one.

fn spectrum_count_hint(&self) -> Option<u64>

A hint about how many spectra are in this data file

fn set_spectrum_count_hint(&mut self, _value: Option<u64>)

fn run_description(&self) -> Option<&MassSpectrometryRun>

Access the MassSpectrometryRun metadata record if it is available

fn run_description_mut(&mut self) -> Option<&mut MassSpectrometryRun>

Mutably access the MassSpectrometryRun metadata record if it is available

fn source_file_name(&self) -> Option<&str>

Get the name of the primary source file, if available

Implementations on Foreign Types

Source

impl<T> MSDataFileMetadata for Box<T>

Source

impl<T> MSDataFileMetadata for Arc<T>

MSDataFileMetadata may be accessed on std::sync::Arc wrapping types that implement the trait, but attempting to use the mutable methods will panic if the underlying instance is already shared.

Implementors

Source

impl MSDataFileMetadata for FileMetadataConfig

Source

impl<C, D, R> MSDataFileMetadata for MZReaderType<R, C, D>

Source

impl<C, D, R, S> MSDataFileMetadata for SpectrumIterator<'_, C, D, S, R>

If the underlying iterator implements MSDataFileMetadata then SpectrumIterator will forward that implementation, assuming it is available.

Source

impl<C, D, S> MSDataFileMetadata for MemorySpectrumSource<C, D, S>

Source

impl<C, D, S> MSDataFileMetadata for SpectrumReceiver<C, D, S>

Source

impl<C, D, S, I> MSDataFileMetadata for StreamingSpectrumIterator<C, D, S, I>

If the underlying iterator implements MSDataFileMetadata then StreamingSpectrumIterator will forward that implementation, assuming it is available.

Source

impl<C, D, S, R> MSDataFileMetadata for IonMobilityFrameIterator<'_, C, D, S, R>

If the underlying iterator implements MSDataFileMetadata then IonMobilityFrameIterator will forward that implementation, assuming it is available.

Source

impl<CP, DP, R, C, D> MSDataFileMetadata for BorrowedGeneric3DIonMobilityFrameSource<'_, CP, DP, R, C, D>

Source

impl<CP, DP, R, C, D> MSDataFileMetadata for Generic3DIonMobilityFrameSource<CP, DP, R, C, D>

Source

impl<R, C, D, CP, DP> MSDataFileMetadata for IMMZReaderType<R, C, D, CP, DP>

Source

impl<R, C, D, S, G> MSDataFileMetadata for IonMobilityFrameGroupingIterator<R, C, D, S, G>

Source

impl<R, C, D, S, G> MSDataFileMetadata for SpectrumGroupingIterator<R, C, D, S, G>