pub enum NativeSpectrumIdentifierFormatTerm {
Show 28 variants
NativeSpectrumIdentifierFormat,
ThermoNativeIDFormat,
WatersNativeIDFormat,
WIFFNativeIDFormat,
BrukerAgilentYEPNativeIDFormat,
BrukerBAFNativeIDFormat,
BrukerFIDNativeIDFormat,
MultiplePeakListNativeIDFormat,
SinglePeakListNativeIDFormat,
ScanNumberOnlyNativeIDFormat,
SpectrumIdentifierNativeIDFormat,
BrukerU2NativeIDFormat,
NoNativeIDFormat,
ShimadzuBiotechNativeIDFormat,
MobilionMBINativeIDFormat,
SCIEXTOFTOFNativeIDFormat,
AgilentMassHunterNativeIDFormat,
SpectrumFromDatabaseIntegerNativeIDFormat,
MascotQueryNumber,
SpectrumFromProteinScapeDatabaseNativeIDFormat,
SpectrumFromDatabaseStringNativeIDFormat,
SCIEXTOFTOFT2DNativeIDFormat,
ScaffoldNativeIDFormat,
BrukerContainerNativeIDFormat,
UIMFNativeIDFormat,
BrukerTDFNativeIDFormat,
ShimadzuBiotechQTOFNativeIDFormat,
BrukerTSFNativeIDFormat,
}Expand description
A text-based schema that defines how native spectrum identifiers are formatted. These patterns are often found in mzML-compatible formats.
Variants
NativeSpectrumIdentifierFormat
native spectrum identifier format - (.+)
ThermoNativeIDFormat
Thermo nativeID format - controllerType=(?<controllerType>\d+) controllerNumber=(?<controllerNumber>\d+) scan=(?<scan>\d+)
WatersNativeIDFormat
Waters nativeID format - function=(?<function>\d+) process=(?<process>\d+) scan=(?<scan>\d+)
WIFFNativeIDFormat
WIFF nativeID format - sample=(?<sample>\d+) period=(?<period>\d+) cycle=(?<cycle>\d+) experiment=(?<experiment>\d+)
BrukerAgilentYEPNativeIDFormat
Bruker/Agilent YEP nativeID format - scan=(?<scan>\d+)
BrukerBAFNativeIDFormat
Bruker BAF nativeID format - scan=(?<scan>\d+)
BrukerFIDNativeIDFormat
Bruker FID nativeID format - file=(?<file>\S+)
MultiplePeakListNativeIDFormat
multiple peak list nativeID format - index=(?<index>\d+)
SinglePeakListNativeIDFormat
single peak list nativeID format - file=(?<file>\S+)
ScanNumberOnlyNativeIDFormat
scan number only nativeID format - scan=(?<scan>\d+)
SpectrumIdentifierNativeIDFormat
spectrum identifier nativeID format - spectrum=(?<spectrum>\d+)
BrukerU2NativeIDFormat
Bruker U2 nativeID format - declaration=(?<declaration>\d+) collection=(?<collection>\d+) scan=(?<scan>\d+)
NoNativeIDFormat
no nativeID format - (.+)
ShimadzuBiotechNativeIDFormat
Shimadzu Biotech nativeID format - source=(?<source>\S+) start=(?<start>\d+) end=(?<end>\d+)
MobilionMBINativeIDFormat
Mobilion MBI nativeID format - frame=(?<frame>\d+) scan=(?<scan>\d+)
SCIEXTOFTOFNativeIDFormat
SCIEX TOF/TOF nativeID format - jobRun=(?<jobRun>\d+) spotLabel=(?<spotLabel>\S+) spectrum=(?<spectrum>\d+)
AgilentMassHunterNativeIDFormat
Agilent MassHunter nativeID format - scanId=(?<scanId>\d+)
SpectrumFromDatabaseIntegerNativeIDFormat
spectrum from database integer nativeID format - databasekey=(?<databasekey>-?\d+)
MascotQueryNumber
Mascot query number - query=(?<query>\d+)
SpectrumFromProteinScapeDatabaseNativeIDFormat
spectrum from ProteinScape database nativeID format - databasekey=(?<databasekey>-?\d+)
SpectrumFromDatabaseStringNativeIDFormat
spectrum from database string nativeID format - databasekey=(?<databasekey>\S+)
SCIEXTOFTOFT2DNativeIDFormat
SCIEX TOF/TOF T2D nativeID format - file=(?<file>\S+)
ScaffoldNativeIDFormat
Scaffold nativeID format - (.+)
BrukerContainerNativeIDFormat
Bruker Container nativeID format - (.+)
UIMFNativeIDFormat
UIMF nativeID format - frame=(?<frame>\d+) scan=(?<scan>\d+) frameType=(?<frameType>\d+)
BrukerTDFNativeIDFormat
Bruker TDF nativeID format - frame=(?<frame>\d+) scan=(?<scan>\d+)
ShimadzuBiotechQTOFNativeIDFormat
Shimadzu Biotech QTOF nativeID format - scan=(?<scan>\d+)
BrukerTSFNativeIDFormat
Bruker TSF nativeID format - frame=(?<frame>\d+)
Implementations
Sourceimpl NativeSpectrumIdentifierFormatTerm
These methods are part of the controlled vocabulary mapping
impl NativeSpectrumIdentifierFormatTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> u32
pub const fn accession(&self) -> u32
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<NativeSpectrumIdentifierFormatTerm>
pub fn from_name(name: &str) -> Option<NativeSpectrumIdentifierFormatTerm>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(
accession: u32,
) -> Option<NativeSpectrumIdentifierFormatTerm>
pub const fn from_accession( accession: u32, ) -> Option<NativeSpectrumIdentifierFormatTerm>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(
curie: &CURIE,
) -> Option<NativeSpectrumIdentifierFormatTerm>
pub const fn from_curie( curie: &CURIE, ) -> Option<NativeSpectrumIdentifierFormatTerm>
Sourcepub const fn from_param(
p: &ParamCow<'static>,
) -> Option<NativeSpectrumIdentifierFormatTerm>
pub const fn from_param( p: &ParamCow<'static>, ) -> Option<NativeSpectrumIdentifierFormatTerm>
Sourcepub fn parents(&self) -> Vec<NativeSpectrumIdentifierFormatTerm>
pub fn parents(&self) -> Vec<NativeSpectrumIdentifierFormatTerm>
Retrieve the list of zero or more terms in the set which are parents of this term.
Sourceimpl NativeSpectrumIdentifierFormatTerm
impl NativeSpectrumIdentifierFormatTerm
Sourcepub fn parser(&self) -> Regex
pub fn parser(&self) -> Regex
Create a new regex::Regex for this identifier format.
Sourcepub fn parse<'h>(&self, ident: &'h str) -> Option<Captures<'h>>
pub fn parse<'h>(&self, ident: &'h str) -> Option<Captures<'h>>
This parses the provided string, returning the captured groups of the ID pattern if they are present
in a regex::Captures structure that can be indexed by group number.
Note
This method creates a new regular expression on each invocation, making it expensive to invoke.
If you must call this repeatedly, instead use NativeSpectrumIdentifierFormatTerm::build to create a
the regular expression once and re-use it directly.
Sourcepub fn build(&self) -> NativeSpectrumIDFormat
pub fn build(&self) -> NativeSpectrumIDFormat
Create a NativeSpectrumIDFormat that owns the Regex produced
by NativeSpectrumIdentifierFormatTerm::parser
Sourcepub fn format<'h>(
&self,
values: impl IntoIterator<Item = ValueRef<'h>>,
) -> String
pub fn format<'h>( &self, values: impl IntoIterator<Item = ValueRef<'h>>, ) -> String
Given the field values of a nativeID format, create string in that format
Note
This method creates a new expression formatter every time.
Use NativeSpectrumIdentifierFormatTerm::build to create a re-useable
parser/formatter.
Sourcepub fn parse_named<'h>(&self, ident: &'h str) -> Vec<(Option<String>, &'h str)>
pub fn parse_named<'h>(&self, ident: &'h str) -> Vec<(Option<String>, &'h str)>
This parses the provided string, returning the capture groups as (name, value) pairs they are present.
Note
This method creates a new regular expression on each invocation, making it expensive to invoke.
If you must call this repeatedly, instead use NativeSpectrumIdentifierFormatTerm::build to create a
the regular expression once and re-use it directly.