pub enum SoftwareTerm {
Show 383 variants
Software,
Xcalibur,
Bioworks,
MassLynx,
FlexAnalysis,
DataExplorer,
_4700Explorer,
MassWolf,
VoyagerBiospectrometryWorkstationSystem,
FlexControl,
ReAdW,
MzStar,
Analyst,
Trapper,
MzWiff,
Proteios,
ProteinLynxGlobalServer,
ProteoWizardSoftware,
ProteomeDiscoverer,
_4000SeriesExplorerSoftware,
GPSExplorer,
LightSightSoftware,
ProteinPilotSoftware,
TissueViewSoftware,
MarkerViewSoftware,
MRMPilotSoftware,
BioAnalyst,
ProID,
ProICAT,
ProQuant,
ProBLAST,
Cliquid,
MIDASWorkflowDesigner,
MultiQuant,
MassHunterDataAcquisition,
MassHunterEasyAccess,
MassHunterQualitativeAnalysis,
MassHunterQuantitativeAnalysis,
MassHunterMetaboliteID,
MassHunterBioConfirm,
GenespringMS,
MassHunterMassProfiler,
METLIN,
SpectrumMillForMassHunterWorkstation,
_6300SeriesIonTrapDataAnalysisSoftware,
AgilentSoftware,
SCIEXSoftware,
AppliedBiosystemsSoftware,
BrukerSoftware,
ThermoFinniganSoftware,
WatersSoftware,
ApexControl,
BioTools,
CLINPROT,
CLINPROTMicro,
CLINPROTRobot,
ClinProTools,
Compass,
CompassForHCTEsquire,
CompassForMicrOTOF,
CompassOpenAccess,
CompassSecurityPack,
CompassXport,
CompassXtract,
DataAnalysis,
DpControl,
EsquireControl,
FlexImaging,
GENOLINK,
GenoTools,
HCTcontrol,
MicrOTOFcontrol,
PolyTools,
ProfileAnalysis,
PROTEINEER,
PROTEINEERDp,
PROTEINEERFc,
PROTEINEERSpII,
PROTEINEERLC,
ProteinScape,
PureDisk,
QuantAnalysis,
SpControl,
TargetAnalysis,
WARPLC,
TOPPSoftware,
BaselineFilter,
DBExporter,
DBImporter,
FileConverter,
FileFilter,
FileMerger,
InternalCalibration,
MapAligner,
MapNormalizer,
NoiseFilter,
PeakPicker,
Resampler,
SpectraFilter,
TOFCalibration,
CustomUnreleasedSoftwareTool,
HyStar,
SRMSoftware,
MaRiMba,
PeptideAttributeCalculationSoftware,
SSRCalc,
Skyline,
TIQAM,
ATAQS,
QuantitationSoftwareName,
Mascot,
SEQUEST,
Phenyx,
Spectronaut,
AcquisitionSoftware,
AnalysisSoftware,
DataProcessingSoftware,
Greylag,
OMSSA,
XTandem,
SpectraST,
MascotParser,
SCIEXTOFTOFSeriesExplorerSoftware,
ProteinExtractor,
MascotDistiller,
MascotIntegra,
Percolator,
ShimadzuCorporationSoftware,
MALDISolutions,
Scaffold,
XCMS,
MaxQuant,
MyriMatch,
DirecTag,
TagRecon,
Pepitome,
Empower,
UNIFY,
LECOSoftware,
ChromaTOFSoftware,
ProgenesisLCMS,
SILACAnalyzer,
ChromaTOFHRTSoftware,
MALDISolutionsMicrobialIdentification,
SQID,
PinPoint,
PymzML,
PEAKSStudio,
PEAKSOnline,
PEAKSNode,
BSISoftware,
DeBunker,
MSQuant,
AscoreSoftware,
ProteinProspector,
MSGF,
MSGFplus,
MicrosoftExcel,
FindPairs,
PAnalyzer,
XTracker,
ProteoSuite,
ITRAQAnalyzer,
TOPPNoiseFilter,
TOPPNoiseFilterGaussian,
TOPPNoiseFilterSGolay,
TOPPPeakPicker,
TOPPPeakPickerHiRes,
TOPPPeakPickerWavelet,
TOPPSpectraFilter,
TOPPSpectraFilterBernNorm,
TOPPSpectraFilterMarkerMower,
TOPPSpectraFilterNLargest,
TOPPSpectraFilterNormalizer,
TOPPSpectraFilterParentPeakMower,
TOPPSpectraFilterScaler,
TOPPSpectraFilterSqrtMower,
TOPPSpectraFilterThresholdMower,
TOPPSpectraFilterWindowMower,
TOPPMapAligner,
TOPPMapAlignerIdentification,
TOPPMapAlignerPoseClustering,
TOPPMapAlignerSpectrum,
TOPPDTAExtractor,
TOPPIDMerger,
TOPPIDFileConverter,
TOPPSpectraMerger,
TOPPMzTabExporter,
TOPPMassTraceExtractor,
TOPPPrecursorMassCorrector,
TOPPHighResPrecursorMassCorrector,
TOPPAdditiveSeries,
TOPPDecharger,
TOPPEICExtractor,
TOPPFeatureFinder,
TOPPFeatureFinderCentroided,
TOPPFeatureFinderRaw,
TOPPFeatureFinderIsotopeWavelet,
TOPPFeatureFinderMetabo,
TOPPFeatureFinderMRM,
TOPPProteinQuantifier,
TOPPConsensusMapNormalizer,
TOPPMapRTTransformer,
TOPPFeatureLinker,
TOPPFeatureLinkerLabeled,
TOPPFeatureLinkerUnlabeled,
TOPPFeatureLinkerUnlabeledQT,
TOPPCompNovo,
TOPPCompNovoCID,
TOPPSoftwareAdaptor,
TOPPInspectAdapter,
TOPPMascotAdapter,
TOPPMascotAdapterOnline,
TOPPOMSSAAdapter,
TOPPPepNovoAdapter,
TOPPXTandemAdapter,
TOPPSpecLibSearcher,
TOPPConsensusID,
TOPPIDConflictResolver,
TOPPIDFilter,
TOPPIDMapper,
TOPPIDPosteriorErrorProbability,
TOPPIDRTCalibration,
TOPPPeptideIndexer,
TOPPPrecursorIonSelector,
TOPPMRMMapper,
TOPPOpenSwathComponent,
TOPPOpenSwathAnalyzer,
TOPPOpenSwathChromatogramExtractor,
TOPPOpenSwathDecoyGenerator,
TOPPOpenSwathFeatureXMLToTSV,
TOPPOpenSwathRTNormalizer,
TOPPProteinInference,
TOPPFalseDiscoveryRate,
ProteoWizardMsconvert,
ProteoWizardIdconvert,
ProteoWizardChainsaw,
ProteoWizardMsaccess,
ProteoWizardSeeMS,
IsobariQ,
MRMaid,
MzidLib,
MzidLibOmssa2Mzid,
MzidLibTandem2Mzid,
MzidLibCsv2Mzid,
MzidLibProteoGrouper,
MzidLibThresholder,
MzidLibPerformEmPAIOnMzid,
MzidLibFalseDiscoveryRate,
MzidLibMzidentml2Csv,
MzidLibCombineSearchEngines,
MzidLibInsertMetaDataFromFasta,
Comet,
Byonic,
TransProteomicPipeline,
TransProteomicPipelineSoftware,
PeptideProphet,
IProphet,
ProteinProphet,
XPRESS,
Libra,
PTMProphet,
ConversionSoftware,
ProCon,
PRIDEConverter2,
Amanda,
Andromeda,
Mzmine,
Maltcms,
MALDISolutionsLCMALDI,
SCiLSSoftware,
SCiLSLab,
PreprocessingSoftware,
PIA,
Anubis,
PostprocessingSoftware,
Maui,
PeptideShaker,
PepFinder,
XiFDR,
Xi,
SkylineMzQuantMLConverter,
ASAPRatio,
Tide,
ProLuCID,
DTASelect,
MSDK,
Morpheus,
OpenXQuest,
FLASHDeconv,
WatersDATAConvert,
MSPathFinder,
NISTMSPepSearch,
MetaMorpheus,
MzR,
MSnbase,
CAMERA,
SmallMoleculeAnalysisSoftware,
ProgenesisQI,
CompoundDiscoverer,
MyCompoundID,
TopPIC,
TopFD,
TopMG,
LipidomicsAnalysisSoftware,
LipidDataAnalyzer,
LipidHunter,
LipidXplorer,
LipidMatch,
Greazy,
LipidBlast,
LipidPro,
LipidFinder,
LipiDex,
LIQUID,
ALEX,
ALEX123,
LIMSA,
LOBSTAHS,
LipidQA,
Proline,
PepNovo,
PNovo,
Novor,
IdentiPy,
MsDeisotope,
PythonPsims,
LPPtiger,
PFind,
I3tms,
MSFragger,
Philosopher,
OpenPepXL,
MSDIAL,
PatternLab,
SIMXL,
QUINXL,
EPIFANY,
ProSight,
TDPortal,
ThermoRawFileParser,
Pyteomics,
PTXQC,
QuaMeterIDFree,
IMonDB,
BiblioSpec,
LibraryCreationSoftware,
PeakForest,
DIANN,
Casanovo,
Goslin,
ANNSoLo,
ChemClipse,
OpenChrom,
WatersConnect,
Spectra,
MetaboAnnotation,
CompoundDb,
QualityControlSoftware,
Rmzqc,
Jmzqc,
Pymzqc,
MzRecal,
SpectrumClusteringSoftware,
Scout,
Kojak,
Quantms,
XQuestXProphet,
PeakView,
Perseus,
FragPipe,
OpenMS,
PLink,
PLink2,
SCIEXOS,
SCIEXMSDataConverter,
TimsControl,
MetaboScape,
TASQ,
InstaNovo,
InstaNovoplus,
MsQuality,
DIAMetric,
}Variants
Software
software - Software related to the recording or transformation of spectra.
Xcalibur
Xcalibur - Thermo Finnigan software for data acquisition and analysis.
Bioworks
Bioworks - Thermo Finnigan software for data analysis of peptides and proteins.
MassLynx
MassLynx - Micromass software for data acquisition and analysis.
FlexAnalysis
FlexAnalysis - Bruker software for data analysis.
DataExplorer
Data Explorer - Applied Biosystems software for data acquisition and analysis.
_4700Explorer
4700 Explorer - Applied Biosystems software for data acquisition and analysis.
MassWolf
massWolf - A software for converting Waters raw directory format to mzXML or mzML. MassWolf was originally developed at the Institute for Systems Biology.
VoyagerBiospectrometryWorkstationSystem
Voyager Biospectrometry Workstation System - Applied Biosystems MALDI-TOF data acquisition and analysis system.
FlexControl
FlexControl - Bruker software for data acquisition.
ReAdW
ReAdW - A software program for converting Thermo Finnigan RAW file format to mzXML or mzML. ReAdW was originally developed at the Institute for Systems Biology. Its whimsical interleaved spelling and capitalization is pronounced ‘readraw’.
MzStar
MzStar - A software program for converting Applied Biosystems wiff file format to mzXML format. MzStar was originally developed at the Institute for Systems Biology. It is now obsoleted by the MzWiff program.
Analyst
Analyst - SCIEX or Applied Biosystems|MDS SCIEX software for data acquisition.
Trapper
Trapper - A software program for converting Agilent MassHunter format to mzXML or mzML. Trapper was originally developed at the Institute for Systems Biology.
MzWiff
MzWiff - A software program for converting Applied Biosystems wiff file format to the mzXML or mzML format. MzWiff is currently maintained at the Institute for Systems Biology. It replaces the slower mzStar program.
Proteios
Proteios - Database application and analysis platform for proteomics.
ProteinLynxGlobalServer
ProteinLynx Global Server - Waters software for data analysis.
ProteoWizardSoftware
ProteoWizard software - ProteoWizard software for data processing and analysis. Primarily developed by the labs of P. Malick and D. Tabb.
ProteomeDiscoverer
Proteome Discoverer - Thermo Scientific software for data analysis of peptides and proteins.
_4000SeriesExplorerSoftware
4000 Series Explorer Software - SCIEX or Applied Biosystems software for data acquisition and analysis.
GPSExplorer
GPS Explorer - SCIEX or Applied Biosystems software for data acquisition and analysis.
LightSightSoftware
LightSight Software - SCIEX or Applied Biosystems|MDS SCIEX software metabolite identification.
ProteinPilotSoftware
ProteinPilot Software - SCIEX or Applied Biosystems|MDS SCIEX software for protein ID and quant.
TissueViewSoftware
TissueView Software - Applied Biosystems|MDS SCIEX software for tissue imaging.
MarkerViewSoftware
MarkerView Software - Applied Biosystems|MDS SCIEX software for metabolomics and biomarker profiling.
MRMPilotSoftware
MRMPilot Software - Applied Biosystems|MDS SCIEX software for MRM assay development.
BioAnalyst
BioAnalyst - Applied Biosystems|MDS SCIEX software for bio-related data exploration.
ProID
Pro ID - Applied Biosystems|MDS SCIEX software for protein identification.
ProICAT
Pro ICAT - Applied Biosystems|MDS SCIEX software for protein ID and quant by ICAT.
ProQuant
Pro Quant - Applied Biosystems|MDS SCIEX software for protein ID and quant by iTRAQ.
ProBLAST
Pro BLAST - Applied Biosystems|MDS SCIEX software for MS-BLAST identification.
Cliquid
Cliquid - SCIEX Cliquid software for data analysis and quantitation.
MIDASWorkflowDesigner
MIDAS Workflow Designer - Applied Biosystems|MDS SCIEX software for MRM assay development.
MultiQuant
MultiQuant - Applied Biosystems|MDS SCIEX software for MRM-based quantitation.
MassHunterDataAcquisition
MassHunter Data Acquisition - Software for data acquisition of 6000 series instruments.
MassHunterEasyAccess
MassHunter Easy Access - Software for open access data acquisition.
MassHunterQualitativeAnalysis
MassHunter Qualitative Analysis - Software for data analysis of data from 6000 series instruments.
MassHunterQuantitativeAnalysis
MassHunter Quantitative Analysis - Software for quantitation of Triple Quadrupole and Quadrupole Time-of-Flight data.
MassHunterMetaboliteID
MassHunter Metabolite ID - Software for identification of metabolites.
MassHunterBioConfirm
MassHunter BioConfirm - Software for protein characterization.
GenespringMS
Genespring MS - Software for quantitation and statistical analysis of TOF and Q-TOF LC/MS data.
MassHunterMassProfiler
MassHunter Mass Profiler - Software for quantitation and statistical analysis of TOF and Q-TOF LC/MS data.
METLIN
METLIN - Personal Metabolite Database for MassHunter Workstation. Software for identification of human metabolites.
SpectrumMillForMassHunterWorkstation
Spectrum Mill for MassHunter Workstation - Software for protein identification and characterization of complex protein digest mixtures.
_6300SeriesIonTrapDataAnalysisSoftware
6300 Series Ion Trap Data Analysis Software - Software for data analysis of 6300 series ion trap mass spectrometers.
AgilentSoftware
Agilent software - Agilent software for data acquisition and analysis.
SCIEXSoftware
SCIEX software - SCIEX or Applied Biosystems software for data acquisition and analysis.
AppliedBiosystemsSoftware
Applied Biosystems software - Applied Biosystems|MDS SCIEX software for data acquisition and analysis.
BrukerSoftware
Bruker software - Bruker software for data acquisition and analysis.
ThermoFinniganSoftware
Thermo Finnigan software - Thermo Finnigan software for data acquisition and analysis.
WatersSoftware
Waters software - Waters software for data acquisition and analysis.
ApexControl
apexControl - Bruker software for data acquisition.
BioTools
BioTools - Bruker software for data analysis.
CLINPROT
CLINPROT - Bruker CLINPROT software.
CLINPROTMicro
CLINPROT micro - Bruker CLINPROT micro software.
CLINPROTRobot
CLINPROT robot - Bruker CLINPROT robot software.
ClinProTools
ClinProTools - Bruker ClinProTools software.
Compass
Compass - Bruker Compass software.
CompassForHCTEsquire
Compass for HCT/esquire - Bruker Compass for HCT/esquire software.
CompassForMicrOTOF
Compass for micrOTOF - Bruker Compass for micrOTOF software.
CompassOpenAccess
Compass OpenAccess - Bruker compass OpenAccess software.
CompassSecurityPack
Compass Security Pack - Bruker compass Security Pack software.
CompassXport
CompassXport - Bruker stand-alone software for data conversion.
CompassXtract
CompassXtract - Bruker software library for data access.
DataAnalysis
DataAnalysis - Bruker software for data analysis.
DpControl
dpControl - Bruker software for data acquisition.
EsquireControl
esquireControl - Bruker software for data acquisition.
FlexImaging
flexImaging - Bruker software for data analysis.
GENOLINK
GENOLINK - Bruker GENOLINK software.
GenoTools
GenoTools - Bruker GenoTools software.
HCTcontrol
HCTcontrol - Bruker software for data acquisition.
MicrOTOFcontrol
micrOTOFcontrol - Bruker software for data acquisition.
PolyTools
PolyTools - Bruker PolyTools software.
ProfileAnalysis
ProfileAnalysis - Bruker software for data analysis.
PROTEINEER
PROTEINEER - Bruker PROTEINEER software.
PROTEINEERDp
PROTEINEER dp - Bruker PROTEINEER dp software.
PROTEINEERFc
PROTEINEER fc - Bruker PROTEINEER fc software.
PROTEINEERSpII
PROTEINEER spII - Bruker PROTEINEER spII software.
PROTEINEERLC
PROTEINEER-LC - Bruker PROTEINEER-LC software.
ProteinScape
ProteinScape - Bruker ProteinScape software.
PureDisk
PureDisk - BrukerPureDisk software.
QuantAnalysis
QuantAnalysis - Bruker software for data analysis.
SpControl
spControl - Bruker software for data acquisition.
TargetAnalysis
TargetAnalysis - Bruker TargetAnalysis software.
WARPLC
WARP-LC - Bruker WARP-LC software.
TOPPSoftware
TOPP software - TOPP (The OpenMS proteomics pipeline) software.
BaselineFilter
BaselineFilter - Removes the baseline from profile spectra using a top-hat filter.
DBExporter
DBExporter - Exports data from an OpenMS database to a file.
DBImporter
DBImporter - Imports data to an OpenMS database.
FileConverter
FileConverter - Converts between different MS file formats.
FileFilter
FileFilter - Extracts or manipulates portions of data from peak, feature or consensus feature files.
FileMerger
FileMerger - Merges several MS files into one file.
InternalCalibration
InternalCalibration - Applies an internal calibration.
MapAligner
MapAligner - OBSOLETE Corrects retention time distortions between maps.
MapNormalizer
MapNormalizer - Normalizes peak intensities in an MS run.
NoiseFilter
NoiseFilter - OBSOLETE Removes noise from profile spectra by using different smoothing techniques.
PeakPicker
PeakPicker - OBSOLETE Finds mass spectrometric peaks in profile mass spectra.
Resampler
Resampler - Transforms an LC/MS map into a resampled map or a png image.
SpectraFilter
SpectraFilter - OBSOLETE Applies a filter to peak spectra.
TOFCalibration
TOFCalibration - Applies time of flight calibration.
CustomUnreleasedSoftwareTool
custom unreleased software tool - A software tool that has not yet been released. The value should describe the software. Please do not use this term for publicly available software - contact the PSI-MS working group in order to have another CV term added.
HyStar
HyStar - Bruker software for hyphenated experiments.
SRMSoftware
SRM software - Software used to predict, select, or optimize transitions or analyze the results of selected reaction monitoring runs.
MaRiMba
MaRiMba - Software used to predict transitions for selected reaction monitoring experiments based on observed spectrum libraries developed and distributed by the Institute for Systems Biology.
PeptideAttributeCalculationSoftware
peptide attribute calculation software - Software used to predict or calculate numerical attributes of peptides.
SSRCalc
SSRCalc - Sequence Specific Retention Calculator estimates the retention time of peptides based on their sequence.
Skyline
Skyline - Software used to predict, select, and optimize transitions as well as analyze the results of selected reaction monitoring runs developed and distributed by the MacCoss lab at the University of Washington.
TIQAM
TIQAM - Software used to predict, select, and optimize transitions for selected reaction monitoring experiments developed and distributed by the Institute for Systems Biology.
ATAQS
ATAQS - Software suite used to predict, select, and optimize transitions as well as analyze the results of selected reaction monitoring runs developed and distributed by the Institute for Systems Biology.
QuantitationSoftwareName
quantitation software name - Quantitation software name.
Mascot
Mascot - The name of the Mascot search engine.
SEQUEST
SEQUEST - The name of the SEQUEST search engine.
Phenyx
Phenyx - The name of the Phenyx search engine.
Spectronaut
Spectronaut - Commercial cross-vendor software for library (peptide centric), and library-free (spectrum centric) analysis and quantification of DIA data.
AcquisitionSoftware
acquisition software - Acquisition software.
AnalysisSoftware
analysis software - Analysis software.
DataProcessingSoftware
data processing software - Data processing software.
Greylag
greylag - Greylag identification software.
OMSSA
OMSSA - Open Mass Spectrometry Search Algorithm was used to analyze the spectra.
XTandem
X!Tandem - X!Tandem was used to analyze the spectra.
SpectraST
SpectraST - Open-source software for mass spectral library creation and searching, developed at the Institute for Systems Biology and the Hong Kong University of Science and Technology. Part of the Trans-Proteomic Pipeline.
MascotParser
Mascot Parser - Mascot Parser was used to analyze the spectra.
SCIEXTOFTOFSeriesExplorerSoftware
SCIEX TOF/TOF Series Explorer Software - SCIEX or Applied Biosystems software for TOF/TOF data acquisition and analysis.
ProteinExtractor
ProteinExtractor - An algorithm for protein determination/assembly integrated into Bruker’s ProteinScape.
MascotDistiller
Mascot Distiller - Mascot Distiller.
MascotIntegra
Mascot Integra - Mascot Integra.
Percolator
Percolator - Percolator.
ShimadzuCorporationSoftware
Shimadzu Corporation software - Shimadzu Corporation software.
MALDISolutions
MALDI Solutions - Shimadzu Biotech software for data acquisition, processing, and analysis.
Scaffold
Scaffold - Scaffold analysis software.
XCMS
XCMS - Bioconductor package XCMS for preprocessing high-throughput, untargeted analyte profiling data.
MaxQuant
MaxQuant - MaxQuant is a quantitative proteomics software package designed for analyzing large mass spectrometric data sets. It is specifically aimed at high resolution MS data.
MyriMatch
MyriMatch - Tabb Lab software for directly comparing peptides in a database to tandem mass spectra.
DirecTag
DirecTag - Tabb Lab software for generating sequence tags from tandem mass spectra.
TagRecon
TagRecon - Tabb Lab software for reconciling sequence tags to a protein database.
Pepitome
Pepitome - Tabb Lab software for spectral library searches on tandem mass spectra.
Empower
Empower - Waters Empower software for liquid chromatography and mass spectrometry acquisition.
UNIFY
UNIFY - Waters UNIFY software for liquid chromatography and mass spectrometry acquisition.
LECOSoftware
LECO software - LECO software for data acquisition and analysis.
ChromaTOFSoftware
ChromaTOF software - Software for acquisition, processing and analysis of data for LECO instruments.
ProgenesisLCMS
Progenesis LC-MS - Software from Nonlinear Dynamics for LC-MS label-free workflow.
SILACAnalyzer
SILACAnalyzer - Software for SILAC workflow.
ChromaTOFHRTSoftware
ChromaTOF HRT software - Software for acquisition, processing and analysis of data for LECO instruments.
MALDISolutionsMicrobialIdentification
MALDI Solutions Microbial Identification - Shimadzu Biotech software for data acquisition, processing, and analysis.
SQID
SQID - Software for data analysis of peptides and proteins.
PinPoint
PinPoint - Thermo Scientific PinPoint SRM analysis software.
PymzML
pymzML - Python module to interface mzML Data.
PEAKSStudio
PEAKS Studio - PEAKS Studio software for data analysis.
PEAKSOnline
PEAKS Online - PEAKS Online software for high throughput data analysis.
PEAKSNode
PEAKS Node - PEAKS Node software for high throughput data analysis.
BSISoftware
BSI software - Bioinformatics Solutions Inc. Software for data processing and analysis.
DeBunker
DeBunker - DeBunker software.
MSQuant
MSQuant - MSQuant software.
AscoreSoftware
Ascore software - Ascore software.
ProteinProspector
ProteinProspector - ProteinProspector software for data acquisition and analysis.
MSGF
MS-GF - MS-GF software used to re-score the peptide-spectrum matches.
MSGFplus
MS-GF+ - MS-GF+ software used to analyze the spectra.
MicrosoftExcel
Microsoft Excel - Microsoft Excel (can be used for spectral counting).
FindPairs
FindPairs - Software e.g. for SILAC and 14N/15N workflow, part of the PeakQuant suite.
PAnalyzer
PAnalyzer - PAnalyzer software for getting protein evidence categories.
XTracker
x-Tracker - X-Tracker generic tool for quantitative proteomics.
ProteoSuite
ProteoSuite - ProteoSuite software for the analysis of quantitative proteomics data.
ITRAQAnalyzer
ITRAQAnalyzer - Software for iTRAQ workflow. Extracts and normalizes iTRAQ information from an MS experiment.
TOPPNoiseFilter
TOPP noise filter - Noise filter component of the TOPP software.
TOPPNoiseFilterGaussian
TOPP NoiseFilterGaussian - Removes noise from profile spectra by using a gaussian smoothing.
TOPPNoiseFilterSGolay
TOPP NoiseFilterSGolay - Removes noise from profile spectra by using a Savitzky-Golay smoothing.
TOPPPeakPicker
TOPP peak picker - Peak picker component of the TOPP software.
TOPPPeakPickerHiRes
TOPP PeakPickerHiRes - Finds mass spectrometric peaks in high-resoluted profile mass spectra.
TOPPPeakPickerWavelet
TOPP PeakPickerWavelet - Finds mass spectrometric peaks with a wavelet algorithm in low-resoluted profile mass spectra.
TOPPSpectraFilter
TOPP spectra filter - Spectra filter component of the TOPP software.
TOPPSpectraFilterBernNorm
TOPP SpectraFilterBernNorm - Applies a Bern et al normalization to peak spectra.
TOPPSpectraFilterMarkerMower
TOPP SpectraFilterMarkerMower - Applies a filter to peak spectra for marked peaks.
TOPPSpectraFilterNLargest
TOPP SpectraFilterNLargest - Retains the n largest peaks of a peak spectra.
TOPPSpectraFilterNormalizer
TOPP SpectraFilterNormalizer - Applies a TIC/maximal intensity normalization to peak spectra.
TOPPSpectraFilterParentPeakMower
TOPP SpectraFilterParentPeakMower - Filters putative unfragmented precursor ions from tandem spectra.
TOPPSpectraFilterScaler
TOPP SpectraFilterScaler - Applies a filter to peak spectra after intensity scaling according to rank.
TOPPSpectraFilterSqrtMower
TOPP SpectraFilterSqrtMower - Applies a filter to peak spectra after intensity scaling to the square root.
TOPPSpectraFilterThresholdMower
TOPP SpectraFilterThresholdMower - Applies a filter of peaks below a given threshold to peak spectra.
TOPPSpectraFilterWindowMower
TOPP SpectraFilterWindowMower - Applies a filter of the largest peaks in a sliding window over a peak spectrum.
TOPPMapAligner
TOPP map aligner - Map aligner component of the TOPP software.
TOPPMapAlignerIdentification
TOPP MapAlignerIdentification - Corrects retention time distortions between maps based on common peptide identifications.
TOPPMapAlignerPoseClustering
TOPP MapAlignerPoseClustering - Corrects retention time distortions between maps using a pose clustering approach.
TOPPMapAlignerSpectrum
TOPP MapAlignerSpectrum - Corrects retention time distortions between maps by spectrum alignment.
TOPPDTAExtractor
TOPP DTAExtractor - Extracts spectra of an MS run file to several files in DTA format.
TOPPIDMerger
TOPP IDMerger - Merges several protein/peptide identification files into one file.
TOPPIDFileConverter
TOPP IDFileConverter - Converts identification engine file formats.
TOPPSpectraMerger
TOPP SpectraMerger - Merges spectra from an LC/MS map, either by precursor or by RT blocks.
TOPPMzTabExporter
TOPP MzTabExporter - Exports various XML formats to an mzTab file.
TOPPMassTraceExtractor
TOPP MassTraceExtractor - Annotates mass traces in centroided LC/MS maps.
TOPPPrecursorMassCorrector
TOPP PrecursorMassCorrector - Correct the precursor entries of tandem MS scans.
TOPPHighResPrecursorMassCorrector
TOPP HighResPrecursorMassCorrector - Performs precursor mz correction on centroided high resolution data.
TOPPAdditiveSeries
TOPP AdditiveSeries - Computes an additive series to quantify a peptide in a set of samples.
TOPPDecharger
TOPP Decharger - Decharges and merges different feature charge variants of the same chemical entity.
TOPPEICExtractor
TOPP EICExtractor - Quantifies signals at given positions in (raw or picked) LC/MS maps.
TOPPFeatureFinder
TOPP feature finder - Feature finder component of the TOPP software.
TOPPFeatureFinderCentroided
TOPP FeatureFinderCentroided - Detects two-dimensional features in centroided LC-MS data.
TOPPFeatureFinderRaw
TOPP FeatureFinderRaw - Detects two-dimensional features in uncentroided LC-MS data.
TOPPFeatureFinderIsotopeWavelet
TOPP FeatureFinderIsotopeWavelet - Detects two-dimensional features in uncentroided LC-MS data with a wavelet algorithm.
TOPPFeatureFinderMetabo
TOPP FeatureFinderMetabo - Detects two-dimensional features in centroided LC-MS data of metabolites.
TOPPFeatureFinderMRM
TOPP FeatureFinderMRM - Quantifies features LC-MS/MS MRM data.
TOPPProteinQuantifier
TOPP ProteinQuantifier - Computes protein abundances from annotated feature/consensus maps.
TOPPConsensusMapNormalizer
TOPP ConsensusMapNormalizer - Normalizes maps of one consensus XML file (after linking).
TOPPMapRTTransformer
TOPP MapRTTransformer - Applies retention time transformations to maps.
TOPPFeatureLinker
TOPP feature linker - Feature linker component of the TOPP software.
TOPPFeatureLinkerLabeled
TOPP FeatureLinkerLabeled - Groups corresponding isotope-labeled features in a feature map.
TOPPFeatureLinkerUnlabeled
TOPP FeatureLinkerUnlabeled - Groups corresponding features from multiple maps.
TOPPFeatureLinkerUnlabeledQT
TOPP FeatureLinkerUnlabeledQT - Groups corresponding features from multiple maps using a quality threshold clustering approach.
TOPPCompNovo
TOPP CompNovo - Performs a peptide/protein identification with the CompNovo engine.
TOPPCompNovoCID
TOPP CompNovoCID - Performs a peptide/protein identification with the CompNovo engine in collision-induced dissociation (CID) mode.
TOPPSoftwareAdaptor
TOPP software adaptor - Software adaptor to an external program in the TOPP software.
TOPPInspectAdapter
TOPP InspectAdapter - Identifies MS2 spectra using the external program Inspect.
TOPPMascotAdapter
TOPP MascotAdapter - Identifies MS2 spectra using the external program Mascot.
TOPPMascotAdapterOnline
TOPP MascotAdapterOnline - Identifies MS2 spectra using the online version of the external program Mascot.
TOPPOMSSAAdapter
TOPP OMSSAAdapter - Identifies MS2 spectra using the external program OMSSA.
TOPPPepNovoAdapter
TOPP PepNovoAdapter - Identifies MS2 spectra using the external program PepNovo.
TOPPXTandemAdapter
TOPP XTandemAdapter - Identifies MS2 spectra using the external program XTandem.
TOPPSpecLibSearcher
TOPP SpecLibSearcher - Identifies peptide MS2 spectra by spectral matching with a searchable spectral library.
TOPPConsensusID
TOPP ConsensusID - Computes a consensus identification from peptide identifications of several identification engines.
TOPPIDConflictResolver
TOPP IDConflictResolver - Resolves ambiguous annotations of features with peptide identifications.
TOPPIDFilter
TOPP IDFilter - Filters results from protein or peptide identification engines based on different criteria.
TOPPIDMapper
TOPP IDMapper - Assigns protein/peptide identifications to feature or consensus features.
TOPPIDPosteriorErrorProbability
TOPP IDPosteriorErrorProbability - Estimates posterior error probabilities using a mixture model.
TOPPIDRTCalibration
TOPP IDRTCalibration - Calibrate Retention times of peptide hits to standards.
TOPPPeptideIndexer
TOPP PeptideIndexer - Refreshes the protein references for all peptide hits.
TOPPPrecursorIonSelector
TOPP PrecursorIonSelector - A tool for precursor ion selection based on identification results.
TOPPMRMMapper
TOPP MRMMapper - MRMMapper maps measured chromatograms (mzML) and the transitions used (TraML).
TOPPOpenSwathComponent
TOPP OpenSwath component - OpenSwath component of the TOPP software.
TOPPOpenSwathAnalyzer
TOPP OpenSwathAnalyzer - Picks peaks and finds features in an SRM experiment.
TOPPOpenSwathChromatogramExtractor
TOPP OpenSwathChromatogramExtractor - Extract chromatograms (XIC) from a MS2 map file.
TOPPOpenSwathDecoyGenerator
TOPP OpenSwathDecoyGenerator - Generates decoys according to different models for a specific TraML.
TOPPOpenSwathFeatureXMLToTSV
TOPP OpenSwathFeatureXMLToTSV - Converts a featureXML to a mProphet tsv (tab separated values).
TOPPOpenSwathRTNormalizer
TOPP OpenSwathRTNormalizer - Generates a transformation file for retention time space into normalized space.
TOPPProteinInference
TOPP ProteinInference - Infer proteins from a list of (high-confidence) peptides.
TOPPFalseDiscoveryRate
TOPP FalseDiscoveryRate - Estimates the false discovery rate on peptide and protein level using decoy searches.
ProteoWizardMsconvert
ProteoWizard msconvert - Converts, filters, and processes mass spectrometry data in variety of formats.
ProteoWizardIdconvert
ProteoWizard idconvert - Converts, filters, and processes identifications from shotgun proteomics experiments.
ProteoWizardChainsaw
ProteoWizard chainsaw - Filters and processes protein sequence databases.
ProteoWizardMsaccess
ProteoWizard msaccess - Filters, processes, and displays mass spectrometry data in a variety of ways.
ProteoWizardSeeMS
ProteoWizard SeeMS - An interactive GUI application to view and filter mass spectrometry data in a variety of formats.
IsobariQ
IsobariQ - A quantitative software package designed for analysis of IPTL, TMT and iTRAQ data.
MRMaid
MRMaid - A web-based SRM assay design tool whose transitions are generated by mining the millions of identified peptide spectra held in the EBI’s PRIDE database.
MzidLib
mzidLib - A library of Java routines for manipulating mzIdentML files.
MzidLibOmssa2Mzid
mzidLib:Omssa2Mzid - A converter for OMSSA OMX to mzIdentML.
MzidLibTandem2Mzid
mzidLib:Tandem2Mzid - A converter for Tandem XML to mzIdentML.
MzidLibCsv2Mzid
mzidLib:Csv2Mzid - A converter for CSV files (following OMSSA CSV style) to mzIdentML.
MzidLibProteoGrouper
mzidLib:ProteoGrouper - A generic and parameterizable protein inference algorithm for mzIdentML files.
MzidLibThresholder
mzidLib:Thresholder - A routine for keeping only identifications passing a given threshold or setting passThreshold to true or false for SpectrumIdentificationItem or ProteinDetectionHypothesis in mzIdentML files.
MzidLibPerformEmPAIOnMzid
mzidLib:Perform emPAI on mzid - A routine for adding emPAI quantitative values to an mzIdentML file.
MzidLibFalseDiscoveryRate
mzidLib:FalseDiscoveryRate - A routine for calculating local FDR, q-value and FDRScore for mzIdentML files, based on a decoy search.
MzidLibMzidentml2Csv
mzidLib:Mzidentml2Csv - A tool for converting mzIdentML files to CSV format.
MzidLibCombineSearchEngines
mzidLib:CombineSearchEngines - A tool for combining results analysed in parallel in two or three search engines into a single mzIdentML file.
MzidLibInsertMetaDataFromFasta
mzidLib:InsertMetaDataFromFasta - A tool for adding additional meta data from a FASTA file to DBSequence entries (sequence and description) in mzIdentML files.
Comet
Comet - Comet open-source sequence search engine developed at the University of Washington.
Byonic
Byonic - Byonic search engine from Protein Metrics.
TransProteomicPipeline
Trans-Proteomic Pipeline - A suite of open source tools for the processing of MS2 proteomics data developed by the Seattle Proteome Center at the Institute for Systems Biology.
TransProteomicPipelineSoftware
Trans-Proteomic Pipeline software - A software program that is a component of the Trans-Proteomic Pipeline.
PeptideProphet
PeptideProphet - A program in the TPP that calculates PSM probabilities for MS2 proteomics data searched with any of the supported sequence or spectral library search engines via the pepXML format.
IProphet
iProphet - A program in the TPP that calculates distinct peptide probabilities based on several lines of corroborating evidence including search results from multiple search engines via the pepXML format.
ProteinProphet
ProteinProphet - A program in the TPP that calculates protein-level probabilities based on input PSM or peptide-level probabilities from PeptideProphet or iProphet. The output is written in the protXML format.
XPRESS
XPRESS - A program in the TPP that calculates PSM-level abundances based on 2-channel isotope-labelled data such as ICAT, SILAC, etc.
Libra
Libra - A program in the TPP that calculates PSM, peptide, and protein-level abundances based on N-channel isobaric label peptide data such as iTRAQ, TMT, etc.
PTMProphet
PTMProphet - A program in the TPP that calculates PTM localization probabilities by re-analyzing the peaks that are available to distinguish between possible modification sites.
ConversionSoftware
conversion software - Computer software primarily designed to convert data represented in one format to another format, sometimes with minor data alterations in the process.
ProCon
ProCon - Java software designed to convert one of several proteomics identification results formats into mzIdentML or PRIDE XML.
PRIDEConverter2
PRIDE Converter2 - Java software designed to convert one of several proteomics identification results formats into PRIDE XML.
Amanda
Amanda - Amanda scoring system for PSM identification.
Andromeda
Andromeda - Andromeda is a peptide search engine.
Mzmine
mzmine - A framework for differential analysis of mass spectrometry data.
Maltcms
Maltcms - Modular Application Toolkit for Chromatography Mass-Spectrometry is an application framework mainly for developers.
MALDISolutionsLCMALDI
MALDI Solutions LC-MALDI - Software for automated LC-MALDI analysis and reporting.
SCiLSSoftware
SCiLS software - SCiLS software for data acquisition and analysis.
SCiLSLab
SCiLS Lab - SCiLS Lab software.
PreprocessingSoftware
preprocessing software - Preprocessing software.
PIA
PIA - PIA - Protein Inference Algorithms, a toolbox for protein inference and identification analysis.
Anubis
Anubis - Anubis software for selected reaction monitoring data.
PostprocessingSoftware
postprocessing software - Postprocessing software.
Maui
Maui - The Maltcms Graphical User Interface.
PeptideShaker
PeptideShaker - PeptideShaker is a software for the interpretation of proteomics identification results.
PepFinder
PepFinder - Thermo Scientific PepFinder BioPharma analysis software.
XiFDR
xiFDR - Target/Decoy based FDR estimation for crosslinking peptide-identifications.
Xi
xi - Search engine for crosslinked peptides.
SkylineMzQuantMLConverter
Skyline mzQuantML converter - A software package to convert Skyline report to mzQuantML.
ASAPRatio
ASAPRatio - A program in the TPP that calculates PSM, peptide, and protein-level abundances based on 2-channel isotope-labelled data such as ICAT, SILAC, etc.
Tide
Tide - Tide open-source sequence search program developed at the University of Washington.
ProLuCID
ProLuCID - The SEQUEST-like sequence search engine ProLuCID, developed in the Yates Lab at the Scripps Research Institute.
DTASelect
DTASelect - Analysis software designed to reassemble the SEQUEST peptide identifications and to highlight the most significant matches.
MSDK
MSDK - Mass Spectrometry Development Kit (MSDK) is a Java library of algorithms for processing of mass spectrometry data.
Morpheus
Morpheus - Morpheus search engine.
OpenXQuest
OpenXQuest - Cross-Linking MS search engine.
FLASHDeconv
FLASHDeconv - Ultrafast, High-Quality Feature Deconvolution for Top-Down Proteomics.
WatersDATAConvert
Waters DATA Convert - Software for processing and exporting Waters MassLynx and waters_connect data.
MSPathFinder
MSPathFinder - PNNL top-down/bottom-up analysis software for identifying peptides and proteoforms in fragmentation mass spectra.
NISTMSPepSearch
NIST MSPepSearch - Search tool of the NIST (National Institute of Standards and Technology) for spectral library searches.
MetaMorpheus
MetaMorpheus - MetaMorpheus search engine.
MzR
mzR - Bioconductor package mzR for reading and writing mass spectrometry data files.
MSnbase
MSnbase - Bioconductor package MSnbase provides infrastructure for manipulation, processing and visualization of mass spectrometry and proteomics data, ranging from raw to quantitative and annotated data.
CAMERA
CAMERA - Bioconductor package CAMERA for annotation of peak lists generated by xcms, rule based annotation of isotopes and adducts, isotope validation, EIC correlation based tagging of unknown adducts and fragments.
SmallMoleculeAnalysisSoftware
small molecule analysis software - Software for the analysis of small molecules.
ProgenesisQI
Progenesis QI - Metabolomics analysis software for LC-MS data from Nonlinear Dynamics.
CompoundDiscoverer
Compound Discoverer - Metabolomics analysis software from Thermo Fisher Scientific.
MyCompoundID
MyCompoundID - Metabolite identification tool MyCompoundID.
TopPIC
TopPIC - TopPIC: a software tool for top-down mass spectrometry-based proteoform identification and characterization.
TopFD
TopFD - Top-down mass spectral feature detection.
TopMG
TopMG - A mass graph-based approach for the identification of modified proteoforms using top-down tandem mass spectra.
LipidomicsAnalysisSoftware
lipidomics analysis software - Lipidomics analysis software.
LipidDataAnalyzer
Lipid Data Analyzer - Lipid Data Analyzer software for lipid quantification.
LipidHunter
LipidHunter - Software for identification of phospholipids by high-throughput processing of LC-MS and shotgun lipidomics datasets.
LipidXplorer
LipidXplorer - Software for consensual cross-platform lipidomics.
LipidMatch
LipidMatch - An automated workflow for rule-based lipid identification using untargeted high-resolution tandem mass spectrometry data.
Greazy
Greazy - Open-source software for automated phospholipid tandem mass spectrometry identification.
LipidBlast
LipidBlast - LC-MS-based lipidomics and automated identification of lipids using the LipidBlast in-silico MS/MS library.
LipidPro
Lipid-Pro - A computational lipid identification solution for untargeted lipidomics on data-independent acquisition tandem mass spectrometry platforms.
LipidFinder
LipidFinder - A computational workflow for the discovery of lipids for the identification of eicosanoid-phosphoinositides in platelets.
LipiDex
LipiDex - An integrated software package for high-confidence lipid identification.
LIQUID
LIQUID - An-open source software for identifying lipids in LC-MS/MS-based lipidomics data.
ALEX
ALEX - Analysis of lipid experiments, a calculator for m/z values of intact lipid molecules (MS1).
ALEX123
ALEX123 - Analysis of lipid experiments 123, a calculator with m/z values of intact lipid molecules (MS1) and their fragment ions at the MS2 and MS3 level.
LIMSA
LIMSA - Software tool for the quantitative analysis of mass spectrometric lipidome data.
LOBSTAHS
LOBSTAHS - Adduct-Based lipidomics software for the discovery and identification of oxidative stress biomarkers.
LipidQA
LipidQA - Lipid qualitative/quantitative analysis software for identification and quantitation of complex lipid molecular species.
Proline
Proline - The Proline software suite for mass spectrometry based proteomics.
PepNovo
PepNovo - PepNovo tool for de novo peptide sequencing.
PNovo
pNovo - pNovo tool for de novo peptide sequencing and identification using HCD spectra.
Novor
Novor - Novor real-time peptide de novo sequencing software tool.
IdentiPy
IdentiPy - IdentiPy.
MsDeisotope
ms_deisotope - ms_deisotope, a library for deisotoping and charge state deconvolution of mass spectra.
PythonPsims
python-psims - python-psims, a library for generating mzML and mzIdentML.
LPPtiger
LPPtiger - Software for lipidome-specific prediction and identification of oxidized phospholipids from LC-MS datasets.
PFind
pFind - Sequence-tag-based search engine pFind.
I3tms
i3tms - i3-tms search engine and data-analysis software.
MSFragger
MSFragger - A database search-based peptide identification tool.
Philosopher
Philosopher - General proteomics processing toolkit for shotgun proteomics.
OpenPepXL
OpenPepXL - Cross-Linking MS search engine.
MSDIAL
MS-DIAL - Data processing software for untargeted metabolomics and lipidomics that supports multiple instruments and MS vendors.
PatternLab
PatternLab - PatternLab for Proteomics is an integrated computational environment for analyzing shotgun proteomic data.
SIMXL
SIM-XL - Identifying crosslinked peptides in complex protein mixtures
QUINXL
QUIN-XL - Quantification of crosslinked peptides in complex protein mixtures
EPIFANY
EPIFANY - A Method for Efficient High-Confidence Protein Inference. The tool is part of the OpenMS framework
ProSight
ProSight - ProSight: Database search engine for top-down proteomics.
TDPortal
TDPortal - TDPortal: Database search engine for top-down proteomics.
ThermoRawFileParser
ThermoRawFileParser - Cross-platform software to convert Thermo RAW files to a number of open formats.
Pyteomics
pyteomics - Python module that helps handling various proteomics data analysis tasks.
PTXQC
PTX-QC - Proteomics (PTX) - QualityControl (QC) software for QC report generation and visualization.
QuaMeterIDFree
QuaMeter IDFree - QuaMeter IDFree software for QC metric calculation.
IMonDB
iMonDB - iMonDB software to extract, store, and manage mass spectrometry instrument parameters from raw data files.
BiblioSpec
BiblioSpec - A suite of software tools for creating and searching MS/MS peptide spectrum libraries, developed at the University of Washington
LibraryCreationSoftware
library creation software - Library creation software
PeakForest
PeakForest - comprehensive infrastructure to organize, curate and share a multi- instrument spectral library for metabolomics data annotation developed and distributed by the French National infrastructure in metabolomics and fluxomics (MetaboHUB).
DIANN
DIA-NN - A universal software for data-independent acquisition (DIA) proteomics data processing
Casanovo
Casanovo - Casanovo is a deep learning-based de novo spectrum identification tool. Official website https://github.com/Noble-Lab/casanovo/.
Goslin
Goslin - The Goslin implementations parse common lipid name dialects and normalize them to the recent lipid shorthand nomenclature based on grammars on succinct lipid nomenclature.
ANNSoLo
ANN-SoLo - ANN-SoLo (Approximate Nearest Neighbor Spectral Library) is a spectral library search engine for fast and accurate open modification searching. ANN-SoLo uses approximate nearest neighbor indexing to speed up open modification searching by selecting only a limited number of the most relevant library spectra to compare to an unknown query spectrum. This is combined with a cascade search strategy to maximize the number of identified unmodified and modified spectra while strictly controlling the false discovery rate and the shifted dot product score to sensitively match modified spectra to their unmodified counterpart.
ChemClipse
ChemClipse - ChemClipse is part of the Eclipse Science project. Primarily developed by Lablicate GmbH.
OpenChrom
OpenChrom - OpenChrom is an Open Source software for data processing and analysis. Based upon Eclipse ChemClipse.
WatersConnect
waters_connect - Waters Corporation waters_connect software for liquid chromatography and mass spectrometry acquisition and processing.
Spectra
Spectra - Bioconductor package Spectra for mass spectrometry data representation and processing.
MetaboAnnotation
MetaboAnnotation - Bioconductor package MetaboAnnotation for annotation of untargeted metabolomics data.
CompoundDb
CompoundDb - Bioconductor package CompoundDb for creation, usage and maintenance of public or library-specific annotation databases and spectra libraries.
QualityControlSoftware
quality control software - Software that creates or manipulates QC-related data.
Rmzqc
rmzqc - An R package for reading, validating, and writing mzQC files.
Jmzqc
jmzqc - A Java package for reading, validating, and writing mzQC files.
Pymzqc
pymzqc - A Python package for reading, validating, and writing mzQC files.
MzRecal
mzRecal - MS1 recalibration using identified peptides as internal calibrants.
SpectrumClusteringSoftware
spectrum clustering software - Software designed to group multiple mass spectra by high similarity, generally with the goal of grouping replicate spectra derived from the same analyte.
Scout
Scout - Identifying crosslinked peptides in complex protein mixtures
Kojak
Kojak - Kojak open-source crosslinked peptide sequence search engine developed at the Institute for Systems Biology.
Quantms
quantms - Cloud-based pipeline for quantitative proteomics that enables the reanalysis of public proteomics data.
XQuestXProphet
xQuest/xProphet - A software to identify cross-linked peptides from LC-MS/MS spectra.
PeakView
PeakView - A software for spectral analysis and data interrogation in qualitative review of LC-MS and MS/MS data.
Perseus
Perseus - A software for interpreting protein quantification, interaction and post-translational modification data.
FragPipe
FragPipe - A computational platform for analyzing mass spectrometry-based proteomics data.
OpenMS
OpenMS - A software for LC-MS data management and analysis.
PLink
pLink - A tool for the analysis of chemically cross-linked proteins using mass spectrometry.
PLink2
pLink2 - Upgraded version of pLink tool, provides a graphical user interface and faster with newly designed index structure.
SCIEXOS
SCIEX OS - SCIEX OS software.
SCIEXMSDataConverter
SCIEX MS Data Converter - A software for converting SCIEX wiff or wiff2 format to mzML.
TimsControl
timsControl - Bruker software for data acquisition.
MetaboScape
MetaboScape - Bruker software for untargeted metabolomics and lipidomics data analysis.
TASQ
TASQ - Bruker software for target screening and quantitation.
InstaNovo
InstaNovo - InstaNovo is a deep learning based tool using a Transformer architecture for de novo peptide sequencing.
InstaNovoplus
InstaNovo+ - InstaNovo+ is a deep learning based tool using a Diffusion architecture for de novo peptide sequencing.
MsQuality
MsQuality - MsQuality – an interoperable open-source package for the calculation of standardized quality metrics of mass spectrometry data.
DIAMetric
DIAMetric - DIAMetric is a Data-Independent Acquisition Quality Metric Generator.
Implementations
Sourceimpl SoftwareTerm
These methods are part of the controlled vocabulary mapping
impl SoftwareTerm
These methods are part of the controlled vocabulary mapping
Sourcepub const fn accession(&self) -> u32
pub const fn accession(&self) -> u32
Retrieve the accession number for this term, independent of its controlled vocabulary
Sourcepub const fn controlled_vocabulary(&self) -> ControlledVocabulary
pub const fn controlled_vocabulary(&self) -> ControlledVocabulary
Retrieve the controlled vocabulary this term belongs to
Sourcepub const fn name(&self) -> &'static str
pub const fn name(&self) -> &'static str
Retrieve the plain text human readable name for this term
Sourcepub fn from_name(name: &str) -> Option<SoftwareTerm>
pub fn from_name(name: &str) -> Option<SoftwareTerm>
Attempt to map a string by name to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn from_accession(accession: u32) -> Option<SoftwareTerm>
pub const fn from_accession(accession: u32) -> Option<SoftwareTerm>
Attempt to map the numeric accession number to retrieve one of the terms from this set.
If no match is found, None is returned.
Sourcepub const fn to_param(self) -> ParamCow<'static>
pub const fn to_param(self) -> ParamCow<'static>
Convert this term into a ParamCow without a value.
Sourcepub const fn from_curie(curie: &CURIE) -> Option<SoftwareTerm>
pub const fn from_curie(curie: &CURIE) -> Option<SoftwareTerm>
Sourcepub const fn from_param(p: &ParamCow<'static>) -> Option<SoftwareTerm>
pub const fn from_param(p: &ParamCow<'static>) -> Option<SoftwareTerm>
Sourcepub fn flags(&self) -> SoftwareType
pub fn flags(&self) -> SoftwareType
Retrieve a term set specific set of flags
Sourcepub fn parents(&self) -> Vec<SoftwareTerm>
pub fn parents(&self) -> Vec<SoftwareTerm>
Retrieve the list of zero or more terms in the set which are parents of this term.