pub struct FileDescription {
pub contents: Vec<Param>,
pub source_files: Vec<SourceFile>,
}Expand description
A description of the file data file and its contents
Fields
contents: Vec<Param>Descriptors of the content spectra
source_files: Vec<SourceFile>Any source files involved in producing the current file, such as vendor raw files.
Implementations
Sourceimpl FileDescription
impl FileDescription
pub fn new( contents: Vec<Param>, source_files: Vec<SourceFile>, ) -> FileDescription
Sourcepub fn has_ms1_spectra(&self) -> bool
pub fn has_ms1_spectra(&self) -> bool
Checks to see if the “MS1 spectrum” term is present in the file contents
Note: This does not actually inspect the spectra in the file, only the metadata, which may be incorrect/missing.
Sourcepub fn has_msn_spectra(&self) -> bool
pub fn has_msn_spectra(&self) -> bool
Checks to see if the “MSn spectrum” term is present in the file contents.
Note: This does not actually inspect the spectra in the file, only the metadata, which may be incorrect/missing.
pub fn has_contents(&self) -> bool