pub struct ProcessingMethod {
pub order: i8,
pub software_reference: String,
pub params: Vec<Param>,
}Expand description
Describe a data processing method stage tied to a specific piece of Software
See https://peptideatlas.org/tmp/mzML1.1.0.html#processingMethod
Fields
order: i8The order of application of this method in the processing pipeline
software_reference: StringThe software used
params: Vec<Param>Controlled vocabulary and user parameters