pub struct Sample {
pub id: String,
pub name: Option<String>,
pub params: Vec<Param>,
}Expand description
A sample that was used to generate a MS dataset
Fields
id: StringA “unique” identifier
name: Option<String>The sample’s human-friendly name
params: Vec<Param>The controlled vocabulary and user parameters of the sample
Implementations