pub struct Software {
pub id: String,
pub version: String,
pub params: Vec<Param>,
}Expand description
A piece of software that was associated with the acquisition, transformation or otherwise processing of mass spectrometry data.
Fields
id: StringA unique identifier for the software within processing metadata
version: StringA string denoting a particular software version, but does no guarantee is given for its format
params: Vec<Param>Any associated vocabulary terms, including actual software name and type
Implementations
Sourceimpl Software
impl Software
pub fn new(id: String, version: String, params: Vec<Param>) -> Software
Sourcepub fn find_software_term(&self) -> Option<SoftwareTerm>
pub fn find_software_term(&self) -> Option<SoftwareTerm>
Find the term defining the software
Sourcepub fn is_analysis(&self) -> bool
pub fn is_analysis(&self) -> bool
Is this software for analysis?
Sourcepub fn is_data_processing(&self) -> bool
pub fn is_data_processing(&self) -> bool
Is this software for data processing?
Sourcepub fn is_acquisition(&self) -> bool
pub fn is_acquisition(&self) -> bool
Is this software for data acquisition?
Sourcepub fn find_unique_id<'a>(
id_stem: &str,
softwares: impl IntoIterator<Item = &'a Software>,
) -> String
pub fn find_unique_id<'a>( id_stem: &str, softwares: impl IntoIterator<Item = &'a Software>, ) -> String
Find a unique identifier from an iterator over software IDs